@@ -1,12 +1,15 @@
 import matplotlib.pyplot as plt
 import seaborn as sns
 import numpy as np
+import scipy.spatial
 import scipy.stats
 import decimal
 import time
 
 from evalAIRR.util.ml import ml_simulated_dataset
 
+from sklearn.preprocessing import MinMaxScaler
+
 def cdf(data):
     data_sorted = np.sort(data)
     p = 1. * np.arange(len(data)) / (len(data) - 1)
@@ -293,10 +296,10 @@ def export_avg_var_scatter_plot(data_R, data_S, axis=0, with_ml_sim = False, ml_
     f, ax = plt.subplots(1, 1)
     f.set_size_inches(9, 7)
     f.suptitle('Feature average value vs variance' if axis == 0 else 'Observation average value vs variance')
-    ax.scatter(data_R_x, data_R_y, c='#5480d1', linewidths=None, alpha=0.5, label='Real')
-    ax.scatter(data_S_x, data_S_y, c='#d65161', linewidths=None, alpha=0.5, label='Simulated')
+    ax.scatter(data_S_x, data_S_y, s=10 if axis == 0 else 40, c='#d65161', linewidths=None, alpha=0.5, label='Simulated')
+    ax.scatter(data_R_x, data_R_y, s=10 if axis == 0 else 40, c='#5480d1', linewidths=None, alpha=0.5, label='Real')
     if with_ml_sim:
-        ax.scatter(data_ML_x, data_ML_y, c='#53d453', linewidths=None, alpha=0.5, label='ML generated')
+        ax.scatter(data_ML_x, data_ML_y, s=10 if axis == 0 else 40, c='#53d453', linewidths=None, alpha=0.5, label='ML generated')
     ax.set_xlabel('Average value')
     ax.set_ylabel('Variance value')
     ax.legend()
@@ -337,6 +340,20 @@ def export_distance_all(data_R, data_S, features_R, features_S, output):
         except: 
             print('[ERROR] Failed to export distance results to file')
 
+def export_jensenshannon(data_R, data_S, output, axis=0):
+    scaler = MinMaxScaler((0, 1))
+    data_R = scaler.fit_transform(data_R)
+    data_S = scaler.fit_transform(data_S)
+    jenshan = scipy.spatial.distance.jensenshannon(data_R, data_S, base=2, axis=axis) ** 2
+    if output:
+        try:
+            with open(output, 'w', encoding="utf-8") as output_file:
+                output_file.write(','.join([str(i) for i in jenshan]))
+            print('[LOG] Jensen-Shannon divergence result file created')
+        except Exception as e: 
+            print(e)
+            print('[ERROR] Failed to export Jensen-Shannon divergence results to file')
+
 def export_obs_distance(observation_index, data_R, data_S):
     if observation_index == 'all':
         print('[ERROR] Observation Euclidean distance report does not support reporting on all observations. Use general report to csv `observation_distance` instead.')
